@@ -3,6 +3,8 @@ import csv
 import logging
 import os
 import random
+import re
+import shutil
 import tempfile
 import zipfile
 from datetime import datetime
@@ -99,7 +101,7 @@ def export_insurees(batch=None, amount=None, dry_run=False):
             writer.writerow([
                 "InsureeNum", "OtherNames", "LastName", "DateOfBirth", "Gender", "Phone", "EffectiveDate",
                 "ValidityDate", "VillageCode", "VillageName", "WardCode", "WardName", "DistrictCode", "DistrictName",
-                "RegionCode", "RegionName",
+                "RegionCode", "RegionName", "Filename", "Error"
             ])
             files_to_zip = [(csv_file_path, "index.csv")]
             zip_file_path = tempfile.NamedTemporaryFile("wb", prefix="insuree_export", suffix=".zip", delete=False)
@@ -122,14 +124,13 @@ def export_insurees(batch=None, amount=None, dry_run=False):
                 district = ward.parent if ward else None
                 region = district.parent if district else None
 
-                if insuree.photo and insuree.photo.photo:
+                if insuree.photo and (insuree.photo.photo or insuree.photo.filename):
                     photo_filename = os.path.join(tmp_dir_name, f"{insuree.chf_id}.jpg")
-                    files_to_zip.append((photo_filename, f"{insuree.chf_id}.jpg"))
                 else:
                     photo_filename = None
 
                 # TODO Make the validity and date formats configurable
-                writer.writerow([
+                row_to_write = [
                     insuree.chf_id,
                     insuree.other_names,
                     insuree.last_name,
@@ -148,14 +149,46 @@ def export_insurees(batch=None, amount=None, dry_run=False):
                     district.name,
                     region.code,
                     region.name,
-                ])
+                    f"{insuree.chf_id}.jpg" if photo_filename else None,
+                    ""
+                ]
 
                 if photo_filename:
-                    with open(photo_filename, "wb") as photo_file:
-                        photo_bytes = insuree.photo.photo.encode("utf-8")
-                        decoded_photo = base64.decodebytes(photo_bytes)
-                        photo_file.write(decoded_photo)
-
+                    if insuree.photo.photo:
+                        with open(photo_filename, "wb") as photo_file:
+                            photo_bytes = insuree.photo.photo.encode("utf-8")
+                            decoded_photo = base64.decodebytes(photo_bytes)
+                            photo_file.write(decoded_photo)
+                        files_to_zip.append((photo_filename, f"{insuree.chf_id}.jpg"))
+                    elif insuree.photo.filename:
+                        # After 2022-10 release gets out, this whole block should be this sole line:
+                        # shutil.copyfile(insuree.photo.full_file_path(), photo_filename)
+                        # But we are missing some deps for Niger, so we reimplement a custom version until then
+                        photo_root_path = os.getenv("PHOTO_ROOT_PATH", None)
+                        if not photo_root_path:
+                            logger.error("PHOTO_ROOT_PATH is not configured, please set it up")
+                        else:
+                            insuree_photo_folder = insuree.photo.folder if insuree.photo.folder else ""
+                            # os.path.join("/xxx", "/Updated", "file.jpg") will result in /Updated, so strip the /
+                            insuree_photo_folder = re.sub("^[/\\\\]", "", insuree_photo_folder)
+                            full_path = os.path.join(
+                                photo_root_path,
+                                insuree_photo_folder,
+                                insuree.photo.filename)
+                            if not os.path.exists(full_path) and "Images" in insuree_photo_folder:
+                                full_path = os.path.join(
+                                    photo_root_path,
+                                    re.sub(r"Images([/\\\\])", "", insuree_photo_folder),
+                                    insuree.photo.filename)
+                            try:
+                                shutil.copyfile(full_path, photo_filename)
+                                files_to_zip.append((photo_filename, f"{insuree.chf_id}.jpg"))
+                            except Exception as exc:
+                                row_to_write[-2] = ""
+                                row_to_write[-1] = f"Could not copy file {full_path}: {exc}"
+                    else:
+                        logger.warning("Photo was identified but neither base64 photo nor filename")
+                writer.writerow(row_to_write)
         if not dry_run:
             BatchInsureeNumber.objects\
                 .filter(insuree_number__in=[i.chf_id for i in to_export])\
